@@ -39,11 +39,11 @@
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <KIconLoader>
 
 #include "calendarview_debug.h"
 #include <QBoxLayout>
 #include <QHeaderView>
+#include <QIcon>
 #include <QTreeWidget>
 #include <QLocale>
 
@@ -153,7 +153,7 @@ public:
     {
     }
 
-    ~ListItemVisitor()
+    ~ListItemVisitor() override
     {
     }
 
@@ -187,7 +187,7 @@ bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
     mItem->start = e->dtStart().toLocalTime();
     mItem->end = e->dtEnd().toLocalTime();
     if (e->recurs()) {
-        const int duration = e->dtStart().secsTo(e->dtEnd());
+        const qint64 duration = e->dtStart().secsTo(e->dtEnd());
         QDateTime kdt(mStartDate, QTime(0, 0, 0));
         kdt = kdt.addSecs(-1);
         mItem->start = e->recurrence()->getNextDateTime(kdt).toLocalTime();
@@ -251,8 +251,7 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
 
 bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
 {
-    static const QPixmap jrnalPxmp = SmallIcon(j->iconName());
-    mItem->setIcon(Summary_Column, jrnalPxmp);
+    mItem->setIcon(Summary_Column, QIcon::fromTheme(j->iconName()));
     if (j->summary().isEmpty()) {
         mItem->setText(Summary_Column,
                        cleanSummary(j->description().section(QLatin1Char('\n'), 0, 0),
@@ -303,8 +302,6 @@ ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent, b
                      this, &ListView::popupMenu);
     QObject::connect(d->mTreeWidget, &QTreeWidget::itemSelectionChanged,
                      this, &ListView::processSelectionChange);
-    // TODO
-    //d->mTreeWidget->restoreLayout( KOGlobals::self()->config(), "ListView Layout" );
 
     d->mSelectedDates.append(QDate::currentDate());
 
